@@ -19,7 +19,7 @@ as.families <- function(fname = "NO",
                         mu = NULL, sigma = NULL, nu = NULL, tau = NULL) {
 
     ## require gamlss.dist
-    if (!require("gamlss.dist", quietly = TRUE, warn.conflicts = FALSE))
+    if (!requireNamespace("gamlss.dist", quietly = TRUE))
         stop("Please install package 'gamlss.dist' for using gamlss families.")
 
     if (is.function(fname))
@@ -31,7 +31,7 @@ as.families <- function(fname = "NO",
     if (mode(fname) != "character" && mode(fname) != "name")
         fname <- as.character(substitute(fname))
 
-    gamlss.fam <- try(gamlss.family(fname), silent = TRUE)
+    gamlss.fam <- try(gamlss.dist::gamlss.family(fname), silent = TRUE)
     if (inherits(gamlss.fam, "try-error"))
         stop(sQuote("fname"), " specifies no valid gamlss family")
 
@@ -61,9 +61,9 @@ as.families <- function(fname = "NO",
 
 gamlss1parMu <- function(mu = NULL, fname = "EXP") {
 
-    FAM <- as.gamlss.family(fname)
+    FAM <- gamlss.dist::as.gamlss.family(fname)
     NAMEofFAMILY <- FAM$family
-    dfun <- paste("d", fname, sep = "")
+    dfun <- paste("gamlss.dist::d", fname, sep = "")
     pdf <- eval(parse(text = dfun))
 
     ## get the loss
@@ -103,9 +103,9 @@ gamlss1parMu <- function(mu = NULL, fname = "EXP") {
 
 gamlss2parMu <- function(mu = NULL, sigma = NULL, fname = "NO") {
 
-    FAM <- as.gamlss.family(fname)
+    FAM <- gamlss.dist::as.gamlss.family(fname)
     NAMEofFAMILY <- FAM$family
-    dfun <- paste("d", fname, sep = "")
+    dfun <- paste("gamlss.dist::d", fname, sep = "")
     pdf <- eval(parse(text = dfun))
 
     ## get the loss
@@ -147,9 +147,9 @@ gamlss2parMu <- function(mu = NULL, sigma = NULL, fname = "NO") {
 
 
 gamlss2parSigma <- function(mu = NULL, sigma = NULL, fname = "NO") {
-    FAM <- as.gamlss.family(fname)
+    FAM <- gamlss.dist::as.gamlss.family(fname)
     NAMEofFAMILY <- FAM$family
-    dfun <- paste("d", fname, sep = "")
+    dfun <- paste("gamlss.dist::d", fname, sep = "")
     pdf <- eval(parse(text = dfun))
 
     ## get the loss
@@ -191,7 +191,7 @@ gamlss2parSigma <- function(mu = NULL, sigma = NULL, fname = "NO") {
 gamlss2parFam <- function(mu = NULL, sigma = NULL, fname = "NO") {
     Families(mu = gamlss2parMu(mu = mu, sigma = sigma, fname = fname),
              sigma = gamlss2parSigma(mu = mu, sigma = sigma, fname = fname),
-             qfun = eval(parse(text=paste0("q", fname))),
+             qfun = eval(parse(text=paste0("gamlss.dist::q", fname))),
              name = fname)
 }
 
@@ -201,9 +201,9 @@ gamlss2parFam <- function(mu = NULL, sigma = NULL, fname = "NO") {
 ## sub-family for Mu
 gamlss3parMu <- function(mu = NULL, sigma = NULL, nu = NULL, fname = "TF") {
 
-    FAM <- as.gamlss.family(fname)
+    FAM <- gamlss.dist::as.gamlss.family(fname)
     NAMEofFAMILY <- FAM$family
-    dfun <- paste("d", fname, sep = "")
+    dfun <- paste("gamlss.dist::d", fname, sep = "")
     pdf <- eval(parse(text = dfun))
 
     ## get the loss
@@ -244,9 +244,9 @@ gamlss3parMu <- function(mu = NULL, sigma = NULL, nu = NULL, fname = "TF") {
 
 
 gamlss3parSigma <- function(mu = NULL, sigma = NULL, nu = NULL, fname = "TF") {
-    FAM <- as.gamlss.family(fname)
+    FAM <- gamlss.dist::as.gamlss.family(fname)
     NAMEofFAMILY <- FAM$family
-    dfun <- paste("d", fname, sep = "")
+    dfun <- paste("gamlss.dist::d", fname, sep = "")
     pdf <- eval(parse(text = dfun))
 
     ## get the loss
@@ -285,9 +285,9 @@ gamlss3parSigma <- function(mu = NULL, sigma = NULL, nu = NULL, fname = "TF") {
 }
 
 gamlss3parNu <- function(mu = NULL, sigma = NULL, nu = NULL, fname = "TF") {
-    FAM <- as.gamlss.family(fname)
+    FAM <- gamlss.dist::as.gamlss.family(fname)
     NAMEofFAMILY <- FAM$family
-    dfun <- paste("d", fname, sep = "")
+    dfun <- paste("gamlss.dist::d", fname, sep = "")
     pdf <- eval(parse(text = dfun))
 
     ## get the loss
@@ -330,7 +330,7 @@ gamlss3parFam <- function(mu = NULL, sigma = NULL, nu = NULL, fname = "TF") {
     Families(mu = gamlss3parMu(mu = mu, sigma = sigma, nu = nu, fname = fname),
              sigma = gamlss3parSigma(mu = mu, sigma = sigma, nu = nu, fname = fname),
              nu = gamlss3parNu(mu = mu, sigma = sigma, nu = nu, fname = fname),
-             qfun = eval(parse(text=paste0("q", fname))),
+             qfun = eval(parse(text=paste0("gamlss.dist::q", fname))),
              name = fname)
 }
 
@@ -341,9 +341,9 @@ gamlss3parFam <- function(mu = NULL, sigma = NULL, nu = NULL, fname = "TF") {
 gamlss4parMu <- function(mu = NULL, sigma = NULL, nu = NULL, tau = NULL,
                          fname = "BCT") {
 
-    FAM <- as.gamlss.family(fname)
+    FAM <- gamlss.dist::as.gamlss.family(fname)
     NAMEofFAMILY <- FAM$family
-    dfun <- paste("d", fname, sep = "")
+    dfun <- paste("gamlss.dist::d", fname, sep = "")
     pdf <- eval(parse(text = dfun))
 
     ## get the loss
@@ -384,9 +384,9 @@ gamlss4parMu <- function(mu = NULL, sigma = NULL, nu = NULL, tau = NULL,
 
 gamlss4parSigma <- function(mu = NULL, sigma = NULL, nu = NULL, tau = NULL,
                             fname = "BCPE") {
-    FAM <- as.gamlss.family(fname)
+    FAM <- gamlss.dist::as.gamlss.family(fname)
     NAMEofFAMILY <- FAM$family
-    dfun <- paste("d", fname, sep = "")
+    dfun <- paste("gamlss.dist::d", fname, sep = "")
     pdf <- eval(parse(text = dfun))
 
     ## get the loss
@@ -428,9 +428,9 @@ gamlss4parSigma <- function(mu = NULL, sigma = NULL, nu = NULL, tau = NULL,
 
 gamlss4parNu <- function(mu = NULL, sigma = NULL, nu = NULL, tau = NULL,
                          fname = "BCPE") {
-    FAM <- as.gamlss.family(fname)
+    FAM <- gamlss.dist::as.gamlss.family(fname)
     NAMEofFAMILY <- FAM$family
-    dfun <- paste("d", fname, sep = "")
+    dfun <- paste("gamlss.dist::d", fname, sep = "")
     pdf <- eval(parse(text = dfun))
 
     ## get the loss
@@ -474,9 +474,9 @@ gamlss4parNu <- function(mu = NULL, sigma = NULL, nu = NULL, tau = NULL,
 
 gamlss4parTau <- function(mu = NULL, sigma = NULL, nu = NULL, tau = NULL,
                           fname = "BCPE") {
-    FAM <- as.gamlss.family(fname)
+    FAM <- gamlss.dist::as.gamlss.family(fname)
     NAMEofFAMILY <- FAM$family
-    dfun <- paste("d", fname, sep = "")
+    dfun <- paste("gamlss.dist::d", fname, sep = "")
     pdf <- eval(parse(text = dfun))
 
     ## get the loss
@@ -521,6 +521,6 @@ gamlss4parFam <- function(mu = NULL, sigma = NULL, nu = NULL, tau = NULL, fname
              sigma = gamlss4parSigma(mu = mu, sigma = sigma, nu = nu, tau = tau, fname = fname),
              nu = gamlss4parNu(mu = mu, sigma = sigma, nu = nu, tau = tau, fname = fname),
              tau = gamlss4parTau(mu = mu, sigma = sigma, nu = nu, tau = tau, fname = fname),
-             qfun = eval(parse(text=paste0("q", fname))),
+             qfun = eval(parse(text=paste0("gamlss.dist::q", fname))),
              name = fname)
 }
